@@ -118,8 +118,8 @@ class TrainerABC(
         kwargs: FrozenDict[str, Any] = FrozenDict(),
     ) -> Dict[str, jnp.ndarray]:
         if (
-            self.save_checkpoint_dir
-            and self.save_every_n_steps
+            self.save_checkpoint_dir is not None
+            and self.save_every_n_steps is not None
             and current_epoch % self.save_every_n_steps == 0
         ):
             self.save_checkpoint(
@@ -253,7 +253,7 @@ class TrainerABC(
                         validation_losses_and_metrics_current_epoch[k]
                     )
                 # check for early stopping
-                if self.is_early_stopping_active and self.early_stopping.should_stop:
+                if self.is_early_stopping_active and self._early_stopping.should_stop:
                     logging.info("[Early Stopping] Stopping training...")
                     break
 
